﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;
using System.Diagnostics;
using Conaito.PowerLight;

namespace Conaito.CSharp_Demo
{
    public partial class frmMain : Form
    {
        ConvertingSettings _convSettings = new ConvertingSettings();
        PowerPointConverter _pptConv = null;
        string _outputFolder = string.Empty;

        public frmMain()
        {
            InitializeComponent();
            _outputFolder = Path.Combine(Application.StartupPath, "output");
        }

        private void btnOpen_Click(object sender, EventArgs e)
        {
            OpenFileDialog ofDialog = new OpenFileDialog();
            ofDialog.Filter = "PowerPoint or XPS file(*.ppt;*.pptx;*.xps)|*.ppt;*.pptx;*.xps";

            if (ofDialog.ShowDialog(this) == DialogResult.OK)
            {                
                try
                {
                    lblStatus.Text = string.Format("Opening file: {0}", ofDialog .FileName);
                    this.Update();

                    _pptConv = new PowerPointConverter();

                    string ext = Path.GetExtension(ofDialog.FileName);
                    if (ext == ".xps")
                        _pptConv.OpenXPSDocument(ofDialog.FileName);
                    else
                        _pptConv.OpenPowerPointFile(ofDialog.FileName);

                    lblFilePath.Text = string.Format("File path: {0}", _pptConv.Document.Path);
                    lblSlidesCount.Text = string.Format("Slides count: {0}", _pptConv.Document.SlidesCount);

                    btnConvert.Enabled = true;
                    btnShowFolder.Enabled = false;
                    lblStatus.Text = string.Format("File opened: {0}", ofDialog.FileName);
                }
                catch (Exception ex)
                {
                    lblStatus.Text = string.Format("ERROR: {0}", ex.Message);
                }
            }            
        }

        private void frmMain_Load(object sender, EventArgs e)
        {
            propertyGrid.SelectedObject = _convSettings;
        }

        private void btnConvert_Click(object sender, EventArgs e)
        {
            
                try
                {
                    lblStatus.Text = "Converting...";
                    this.Update();

                    if (!Directory.Exists(_outputFolder))
                        Directory.CreateDirectory(_outputFolder);

                    if (tbLicenseKey.Text != string.Empty)
                    {
                        _pptConv.SetLicense(tbLicenseKey.Text);
                    }

                    if (!_pptConv.LicenseInfo.IsLicenseValid())
                    {
                        MessageBox.Show(string.Format("License is not valid: {0}", _pptConv.LicenseInfo));
                        return;
                    }

                    _pptConv.Settings = _convSettings;
                    _pptConv.ConvertToSilverlight(_outputFolder);

                    lblStatus.Text = "Converting finished!!!";
                    btnShowFolder.Enabled = true;
                }
                catch (Exception ex)
                {
                    lblStatus.Text = string.Format("ERROR: {0}", ex.Message);
                }
        }

        private void btnShowFolder_Click(object sender, EventArgs e)
        {
            Process.Start(_outputFolder);
        }
    }
}
