﻿Imports System.IO
Imports Conaito.PowerLight

Public Class FrmMain


    Private _convSettings As New ConvertingSettings()
    Private _pptConv As PowerPointConverter = Nothing
    Private _outputFolder As String = String.Empty

    Public Sub New()
        InitializeComponent()
        _outputFolder = Path.Combine(Application.StartupPath, "output")
    End Sub

    Private Sub btnOpen_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnOpen.Click
        Dim ofDialog As New OpenFileDialog()
        ofDialog.Filter = "PowerPoint or XPS file(*.ppt;*.pptx;*.xps)|*.ppt;*.pptx;*.xps"

        If ofDialog.ShowDialog(Me) = DialogResult.OK Then
            Try
                lblStatus.Text = String.Format("Opening file: {0}", ofDialog.FileName)
                Me.Update()

                _pptConv = New PowerPointConverter()

                Dim ext As String = Path.GetExtension(ofDialog.FileName)
                If ext = ".xps" Then
                    _pptConv.OpenXPSDocument(ofDialog.FileName)
                Else
                    _pptConv.OpenPowerPointFile(ofDialog.FileName)
                End If

                lblFilePath.Text = String.Format("File path: {0}", _pptConv.Document.Path)
                lblSlidesCount.Text = String.Format("Slides count: {0}", _pptConv.Document.SlidesCount)

                btnConvert.Enabled = True
                btnShowFolder.Enabled = False
                lblStatus.Text = String.Format("File opened: {0}", ofDialog.FileName)
            Catch ex As Exception
                lblStatus.Text = String.Format("ERROR: {0}", ex.Message)
            End Try
        End If
    End Sub

    Private Sub frmMain_Load(ByVal sender As Object, ByVal e As EventArgs)
        propertyGrid.SelectedObject = _convSettings
    End Sub

    Private Sub btnConvert_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnConvert.Click
       
        Try
            lblStatus.Text = "Converting..."
            Me.Update()

            If Not Directory.Exists(_outputFolder) Then
                Directory.CreateDirectory(_outputFolder)
            End If

            If tbLicenseKey.Text <> String.Empty Then
                _pptConv.SetLicense(tbLicenseKey.Text)
            End If

            If Not (_pptConv.LicenseInfo.IsLicenseValid()) Then
                MessageBox.Show(String.Format("License is not valid: {0}", _pptConv.LicenseInfo))
                Return
            End If

            _pptConv.Settings = _convSettings
            _pptConv.ConvertToSilverlight(_outputFolder)

            lblStatus.Text = "Converting finished!!!"
            btnShowFolder.Enabled = True
        Catch ex As Exception
            lblStatus.Text = String.Format("ERROR: {0}", ex.Message)
        End Try
    End Sub

    Private Sub btnShowFolder_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnShowFolder.Click
        Process.Start(_outputFolder)
    End Sub


    Private Sub FrmMain_Load_1(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
        propertyGrid.SelectedObject = _convSettings
    End Sub
End Class
